summaryrefslogtreecommitdiff
path: root/libavutil/parseutils.c
diff options
context:
space:
mode:
authorDiego Biurrun <diego@biurrun.de>2011-07-02 14:47:34 +0200
committerDiego Biurrun <diego@biurrun.de>2011-07-14 04:09:49 +0200
commit96c1e6d40d389eeb628840030dfe340d762a7ac8 (patch)
treeb66be319363b96162dea4f44073eba331e652d07 /libavutil/parseutils.c
parent806212498ae6b333d0c85dbc9c750580da7c6838 (diff)
doxygen: Make sure parameter names match between .c and .h files.
Diffstat (limited to 'libavutil/parseutils.c')
-rw-r--r--libavutil/parseutils.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/libavutil/parseutils.c b/libavutil/parseutils.c
index 9bac7ab9ce..a7a4518215 100644
--- a/libavutil/parseutils.c
+++ b/libavutil/parseutils.c
@@ -484,7 +484,7 @@ static time_t mktimegm(struct tm *tm)
return t;
}
-int av_parse_time(int64_t *timeval, const char *datestr, int duration)
+int av_parse_time(int64_t *timeval, const char *timestr, int duration)
{
const char *p;
int64_t t;
@@ -506,19 +506,19 @@ int av_parse_time(int64_t *timeval, const char *datestr, int duration)
#undef time
time_t now = time(0);
- len = strlen(datestr);
+ len = strlen(timestr);
if (len > 0)
- lastch = datestr[len - 1];
+ lastch = timestr[len - 1];
else
lastch = '\0';
is_utc = (lastch == 'z' || lastch == 'Z');
memset(&dt, 0, sizeof(dt));
- p = datestr;
+ p = timestr;
q = NULL;
if (!duration) {
- if (!strncasecmp(datestr, "now", len)) {
+ if (!strncasecmp(timestr, "now", len)) {
*timeval = (int64_t) now * 1000000;
return 0;
}
@@ -555,15 +555,15 @@ int av_parse_time(int64_t *timeval, const char *datestr, int duration)
}
}
} else {
/* parse datestr as a duration */
if (p[0] == '-') {
negative = 1;
++p;
}
/* parse datestr as HH:MM:SS */
q = small_strptime(p, time_fmt[0], &dt);
if (!q) {
/* parse datestr as S+ */
dt.tm_sec = strtol(p, (char **)&q, 10);
if (q == p) {
/* the parsing didn't succeed */
@@ -555,15 +555,15 @@ int av_parse_time(int64_t *timeval, const char *datestr, int duration)
}
} else {
- /* parse datestr as a duration */
+ /* parse timestr as a duration */
if (p[0] == '-') {
negative = 1;
@@ -555,15 +555,15 @@ int av_parse_time(int64_t *timeval, const char *datestr, int duration)
}
- /* parse datestr as HH:MM:SS */
+ /* parse timestr as HH:MM:SS */
q = small_strptime(p, time_fmt[0], &dt);
if (!q) {
@@ -555,15 +555,15 @@ int av_parse_time(int64_t *timeval, const char *datestr, int duration)
q = small_strptime(p, time_fmt[0], &dt);
if (!q) {
- /* parse datestr as S+ */
+ /* parse timestr as S+ */
dt.tm_sec = strtol(p, (char **)&q, 10);
if (q == p) {